Superwise SDK
================
Here you can find information that will help you better understand the capabilities of the Superwise SDK and information about all objects and functions. For your convenience, all divide into: <br/>
- Controllers - Entities manager <br/>
- Models - Brings together all the Superwise’s entities <br/>
- Resources - Map entities to Superwise entities<br/>
- Utils - Auxiliary functions<br/>


![Superwise](assets/image.png)
